"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var codegen_exports = {};
__export(codegen_exports, {
  generateCode: () => generateCode
});
module.exports = __toCommonJS(codegen_exports);
var import_promises = require("node:fs/promises");
var import_node_path = __toESM(require("node:path"));
var import_core = require("@graphql-codegen/core");
var typescriptPlugin = __toESM(require("@graphql-codegen/typescript"));
var foundationCloudformationPlugin = __toESM(require("@code-like-a-carpenter/foundation-plugin-cloudformation"));
var foundationTypescriptPlugin = __toESM(require("@code-like-a-carpenter/foundation-plugin-typescript"));
var import_load_config = require("./load-config");
var import_schema = require("./schema");
async function generateCode({ config, outputs }) {
  const relativeRoot = import_node_path.default.dirname(import_node_path.default.resolve(process.cwd(), config));
  const {
    schema: schemaGlob,
    typescriptOutput,
    cloudformationTemplate,
    ...cfg
  } = await (0, import_load_config.loadConfig)(config);
  const schema = await (0, import_schema.loadSchema)(relativeRoot, schemaGlob, [
    foundationCloudformationPlugin.addToSchema,
    foundationTypescriptPlugin.addToSchema
  ]);
  const cwd = process.cwd();
  process.chdir(relativeRoot);
  const promises = [];
  if (outputs.includes("cloudformation")) {
    promises.push(
      generateCloudformation(
        cfg,
        schema,
        import_node_path.default.resolve(relativeRoot, cloudformationTemplate)
      )
    );
  }
  if (outputs.includes("typescript")) {
    promises.push(
      generateTypescript(
        cfg,
        cfg.typescriptConfig,
        schema,
        import_node_path.default.resolve(relativeRoot, typescriptOutput)
      )
    );
  }
  await Promise.all(promises);
  process.chdir(cwd);
}
async function generateCloudformation(config, schema, filename) {
  const result = await (0, import_core.codegen)({
    config: {},
    documents: [],
    filename,
    pluginMap: {
      foundationCloudformation: foundationCloudformationPlugin
    },
    plugins: [{ foundationCloudformation: config }],
    schema
  });
  await (0, import_promises.mkdir)(import_node_path.default.dirname(filename), { recursive: true });
  await (0, import_promises.writeFile)(filename, result);
}
async function generateTypescript(config, typescriptConfig, schema, filename) {
  const result = await (0, import_core.codegen)({
    config: {},
    documents: [],
    filename,
    pluginMap: {
      foundationTypescript: foundationTypescriptPlugin,
      typescript: typescriptPlugin
    },
    plugins: [
      {
        typescript: typescriptConfig
      },
      { foundationTypescript: config }
    ],
    schema
  });
  await (0, import_promises.mkdir)(import_node_path.default.dirname(filename), { recursive: true });
  await (0, import_promises.writeFile)(filename, result);
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  generateCode
});
